==> vdsm-4.17.18.tar.gz: vdsm-4.17.18/vdsm/virt/domain_descriptor.py <==
#
# Copyright 2014 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#
import xml.dom.minidom


class DomainDescriptor(object):

    def __init__(self, xmlStr):
        self._xml = xmlStr
        self._dom = xml.dom.minidom.parseString(xmlStr)
        self._devices = self._first_element_by_tag_name('devices')
        self._devices_hash = hash(self._devices.toxml()
                                  if self._devices is not None else '')

    @classmethod
    def from_id(cls, uuid):
        return cls('<domain><uuid>%s</uuid></domain>' % uuid)

    @property
    def xml(self):
        return self._xml

    @property
    def devices(self):
        return self._devices

    def get_device_elements(self, tagName):
        return self._devices.getElementsByTagName(tagName)

    @property
    def devices_hash(self):
        return self._devices_hash

    def all_channels(self):
        for channel in self.get_device_elements('channel'):
            try:
                name = channel.getElementsByTagName('target')[0].\
                    getAttribute('name')
                path = channel.getElementsByTagName('source')[0].\
                    getAttribute('path')
            except IndexError:
                continue
            else:
                yield name, path

    def _first_element_by_tag_name(self, tagName):
        elements = self._dom.childNodes[0].getElementsByTagName(tagName)
        return elements[0] if elements else None

    def get_memory_size(self):
        """
        Return the vm memory from xml in MiB
        """
        memory = self._first_element_by_tag_name("memory")
        return int(memory.firstChild.nodeValue) // 1024 if memory else None

==> vdsm-4.19.44.tar.gz: vdsm-4.19.44/vdsm/virt/domain_descriptor.py <==
#
# Copyright 2014 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#
from . import vmxml


class MutableDomainDescriptor(object):

    def __init__(self, xmlStr):
        self._dom = vmxml.parse_xml(xmlStr)

    @classmethod
    def from_id(cls, uuid):
        return cls('<domain><uuid>%s</uuid></domain>' % uuid)

    @property
    def xml(self):
        return vmxml.format_xml(self._dom)

    @property
    def devices(self):
        return vmxml.find_first(self._dom, 'devices', None)

    def get_device_elements(self, tagName):
        return vmxml.find_all(self.devices, tagName)

    @property
    def devices_hash(self):
        devices = self.devices
        return hash(vmxml.format_xml(devices) if devices is not None else '')

    def all_channels(self):
        for channel in vmxml.find_all(self.devices, 'channel'):
            name = vmxml.find_attr(channel, 'target', 'name')
            path = vmxml.find_attr(channel, 'source', 'path')
            if name and path:
                yield name, path

    def get_memory_size(self):
        """
        Return the vm memory from xml in MiB
        """
        memory = vmxml.find_first(self._dom, "memory", None)
        return int(vmxml.text(memory)) // 1024 if memory is not None else None


class DomainDescriptor(MutableDomainDescriptor):

    def __init__(self, xmlStr):
        super(DomainDescriptor, self).__init__(xmlStr)
        self._xml = xmlStr
        self._devices = super(DomainDescriptor, self).devices
        self._devices_hash = super(DomainDescriptor, self).devices_hash

    @property
    def xml(self):
        return self._xml

    @property
    def devices(self):
        return self._devices

    @property
    def devices_hash(self):
        return self._devices_hash
